@@ -5,8 +5,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2004-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -14,7 +14,7 @@
 
 // app includes
 #include "debug_utils.h"
-#include "overwritedialog.h"
+#include "overwritedialogue.h"
 #include "codeviewerdialog.h"
 #include "simplecodegenerator.h"
 #include "attribute.h"
@@ -31,14 +31,12 @@
 #include "umloperationlist.h"
 
 // kde includes
-#if QT_VERSION < 0x050000
+#include <klocale.h>
+#include <kmessagebox.h>
 #include <kdialog.h>
-#endif
-#include <KLocalizedString>
-#include <KMessageBox>
+#include <kapplication.h>
 
 // qt includes
-#include <QApplication>
 #include <QDateTime>
 #include <QDir>
 #include <QDomDocument>
@@ -95,11 +93,11 @@ QString CodeGenerator::getUniqueID(CodeDocument * codeDoc)
         id = Uml::ID::toString(c->id()); // this is supposed to be unique already..
     }
     else {
-        QString prefix = QLatin1String("doc");
-        QString id = prefix + QLatin1String("_0");
+        QString prefix = "doc";
+        QString id = prefix + "_0";
         int number = m_lastIDIndex;
-        for (; findCodeDocumentByID(id); ++number) {
-            id = prefix + QLatin1Char('_') + QString::number(number);
+        for ( ; findCodeDocumentByID(id); ++number) {
+            id = prefix + '_' + QString::number(number);
         }
         m_lastIDIndex = number;
     }
@@ -195,10 +193,10 @@ void CodeGenerator::loadFromXMI(QDomElement & qElement)
     // look for our particular child element
     QDomNode node = qElement.firstChild();
     QDomElement element = node.toElement();
-    QString langType = Uml::ProgrammingLanguage::toString(language());
+    QString langType = Uml::ProgrammingLanguage::toString( language() );
 
-    if (qElement.tagName() != QLatin1String("codegenerator")
-        || qElement.attribute(QLatin1String("language"), QLatin1String("UNKNOWN")) != langType) {
+    if (qElement.tagName() != "codegenerator"
+            || qElement.attribute("language", "UNKNOWN") != langType) {
         return;
     }
     // got our code generator element, now load
@@ -207,11 +205,11 @@ void CodeGenerator::loadFromXMI(QDomElement & qElement)
     QDomElement codeDocElement = codeDocNode.toElement();
     while (!codeDocElement.isNull()) {
         QString docTag = codeDocElement.tagName();
-        QString id = codeDocElement.attribute(QLatin1String("id"), QLatin1String("-1"));
-        if (docTag == QLatin1String("sourcecode")) {
+        QString id = codeDocElement.attribute( "id", "-1" );
+        if (docTag == "sourcecode") {
             loadCodeForOperation(id, codeDocElement);
         }
-        else if (docTag == QLatin1String("codedocument") || docTag == QLatin1String("classifiercodedocument")) {
+        else if (docTag == "codedocument" || docTag == "classifiercodedocument") {
             CodeDocument * codeDoc = findCodeDocumentByID(id);
             if (codeDoc) {
                 codeDoc->loadFromXMI(codeDocElement);
@@ -238,7 +236,7 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
     UMLObject *obj = m_document->findObjectById(id);
     if (obj) {
         uDebug() << "found UMLObject for id:" << idStr;
-        QString value = codeDocElement.attribute(QLatin1String("value"));
+        QString value = codeDocElement.attribute("value", "");
 
         UMLObject::ObjectType t = obj->baseType();
         if (t == UMLObject::ot_Operation) {
@@ -259,9 +257,9 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
  */
 void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
 {
-    QString langType = Uml::ProgrammingLanguage::toString(language());
-    QDomElement docElement = doc.createElement(QLatin1String("codegenerator"));
-    docElement.setAttribute(QLatin1String("language"), langType);
+    QString langType = Uml::ProgrammingLanguage::toString( language() );
+    QDomElement docElement = doc.createElement( "codegenerator" );
+    docElement.setAttribute("language",langType);
 
     if (dynamic_cast<SimpleCodeGenerator*>(this)) {
         UMLClassifierList concepts = m_document->classesAndInterfaces();
@@ -273,10 +271,10 @@ void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
                 if (code.isEmpty()) {
                     continue;
                 }
-                QDomElement codeElement = doc.createElement(QLatin1String("sourcecode"));
-                codeElement.setAttribute(QLatin1String("id"), Uml::ID::toString(op->id()));
-                codeElement.setAttribute(QLatin1String("value"), code);
-                docElement.appendChild(codeElement);
+                QDomElement codeElement = doc.createElement("sourcecode");
+                codeElement.setAttribute("id", Uml::ID::toString(op->id()));
+                codeElement.setAttribute("value", code);
+                docElement.appendChild( codeElement );
             }
         }
     }
@@ -284,11 +282,11 @@ void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
         const CodeDocumentList * docList = getCodeDocumentList();
         CodeDocumentList::const_iterator it = docList->begin();
         CodeDocumentList::const_iterator end = docList->end();
-        for (; it != end; ++it) {
+        for ( ; it != end; ++it ) {
             (*it)->saveToXMI(doc, docElement);
         }
     }
-    root.appendChild(docElement);
+    root.appendChild( docElement );
 }
 
 /**
@@ -312,7 +310,7 @@ void CodeGenerator::initFromParentDocument()
     // Walk through the document converting classifiers into
     // classifier code documents as needed (e.g only if doesn't exist)
     UMLClassifierList concepts = m_document->classesAndInterfaces();
-    foreach (UMLClassifier *c, concepts) {
+    foreach (UMLClassifier *c , concepts) {
         // Doesn't exist? Then build one.
         CodeDocument * codeDoc = findCodeDocumentByClassifier(c);
         if (!codeDoc) {
@@ -331,7 +329,7 @@ void CodeGenerator::syncCodeToDocument()
 {
     CodeDocumentList::iterator it = m_codedocumentVector.begin();
     CodeDocumentList::iterator end = m_codedocumentVector.end();
-    for (; it != end; ++it) {
+    for ( ; it != end; ++it ) {
         (*it)->synchronize();
     }
 }
@@ -392,7 +390,6 @@ CodeDocument * CodeGenerator::findCodeDocumentByClassifier(UMLClassifier * class
 void CodeGenerator::writeCodeToFile()
 {
     writeListedCodeDocsToFile(&m_codedocumentVector);
-    finalizeRun();
 }
 
 /**
@@ -404,7 +401,7 @@ void CodeGenerator::writeCodeToFile(UMLClassifierList & concepts)
 {
     CodeDocumentList docs;
 
-    foreach (UMLClassifier *concept, concepts) {
+    foreach (UMLClassifier *concept, concepts ) {
         CodeDocument * doc = findCodeDocumentByClassifier(concept);
         if (doc) {
             docs.append(doc);
@@ -412,7 +409,6 @@ void CodeGenerator::writeCodeToFile(UMLClassifierList & concepts)
     }
 
     writeListedCodeDocsToFile(&docs);
-    finalizeRun();
 }
 
 // Main method. Will write out passed code documents to file as appropriate.
@@ -425,7 +421,7 @@ void CodeGenerator::writeListedCodeDocsToFile(CodeDocumentList * docs)
     // iterate thru all code documents
     CodeDocumentList::iterator it = docs->begin();
     CodeDocumentList::iterator end = docs->end();
-    for (; it != end; ++it)
+    for ( ; it != end; ++it )
     {
         // we need this so we know when to emit a 'codeGenerated' signal
         ClassifierCodeDocument * cdoc = dynamic_cast<ClassifierCodeDocument *>(*it);
@@ -436,7 +432,7 @@ void CodeGenerator::writeListedCodeDocsToFile(CodeDocumentList * docs)
             QString filename = findFileName(*it);
             // check that we may open that file for writing
             QFile file;
-            if (openFile(file, filename)) {
+            if ( openFile(file, filename) ) {
                 QTextStream stream(&file);
                 stream << (*it)->toString() << endl;
                 file.close();
@@ -455,19 +451,6 @@ void CodeGenerator::writeListedCodeDocsToFile(CodeDocumentList * docs)
     }
 }
 
-/**
- * A single call to writeCodeToFile() usually entails processing many
- * items (e.g. as classifiers) for which code is generated.
- * This method is called after all code of one call to writeCodeToFile()
- * has been generated.
- * It can be reimplemented by concrete code generators to perform additional
- * cleanups or other actions that can only be performed once all code has
- * been written.
- */
-void CodeGenerator::finalizeRun()
-{
-}
-
 /**
  * Create a new Code document belonging to this package.
  * @return CodeDocument   pointer to new code document.
@@ -527,21 +510,17 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
     }
 
     int suffix;
-    QPointer<OverwriteDialog> overwriteDialog =
-        new OverwriteDialog(name, outputDirectory.absolutePath(),
-                              m_applyToAllRemaining, qApp->activeWindow());
+    QPointer<OverwriteDialogue> overwriteDialog =
+        new OverwriteDialogue(name, outputDirectory.absolutePath(),
+                              m_applyToAllRemaining, kapp->activeWindow());
     switch (pol->getOverwritePolicy()) {  //if it exists, check the OverwritePolicy we should use
     case CodeGenerationPolicy::Ok:              //ok to overwrite file
         filename = name + extension;
         break;
     case CodeGenerationPolicy::Ask:            //ask if we can overwrite
         switch(overwriteDialog->exec()) {
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::Ok:  //overwrite file
-#else
-        case QDialog::Accepted:
-#endif
-            if (overwriteDialog->applyToAllRemaining()) {
+        case KDialog::Yes:  //overwrite file
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Ok);
                 filename = name + extension;
             }
@@ -549,31 +528,23 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
                 m_applyToAllRemaining = false;
             }
             break;
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::No: //generate similar name
-#else
-        case KDialog::No:
-#endif
+        case KDialog::No: //generate similar name
             suffix = 1;
             while (1) {
-                filename = name + QLatin1String("__") + QString::number(suffix) + extension;
+                filename = name + "__" + QString::number(suffix) + extension;
                 if (!outputDirectory.exists(filename))
                     break;
                 suffix++;
             }
-            if (overwriteDialog->applyToAllRemaining()) {
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Never);
             }
             else {
                 m_applyToAllRemaining = false;
             }
             break;
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::Cancel: //don't output anything
-#else
-        case QDialog::Rejected:
-#endif
-            if (overwriteDialog->applyToAllRemaining()) {
+        case KDialog::Cancel: //don't output anything
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Cancel);
             }
             else {
@@ -587,7 +558,7 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
     case CodeGenerationPolicy::Never: //generate similar name
         suffix = 1;
         while (1) {
-            filename = name + QLatin1String("__") + QString::number(suffix) + extension;
+            filename = name + "__" + QString::number(suffix) + extension;
             if (!outputDirectory.exists(filename)) {
                 break;
             }
@@ -621,9 +592,6 @@ bool CodeGenerator::openFile(QFile & file, const QString &fileName)
     }
     else {
         QDir outputDirectory = UMLApp::app()->commonPolicy()->getOutputDirectory();
-        if (!outputDirectory.exists())
-            outputDirectory.mkpath(outputDirectory.absolutePath());
-
         file.setFileName(outputDirectory.absoluteFilePath(fileName));
         if(!file.open(QIODevice::WriteOnly)) {
             KMessageBox::sorry(0, i18n("Cannot open file %1 for writing. Please make sure the folder exists and you have permissions to write to it.", file.fileName()), i18n("Cannot Open File"));
@@ -641,7 +609,7 @@ bool CodeGenerator::openFile(QFile & file, const QString &fileName)
 QString CodeGenerator::cleanName(const QString &name)
 {
     QString retval = name;
-    retval.replace(QRegExp(QLatin1String("\\W+")), QLatin1String("_"));
+    retval.replace(QRegExp("\\W+"), "_");
     return retval;
 }
 
@@ -662,16 +630,16 @@ QString CodeGenerator::findFileName(CodeDocument * codeDocument)
     // if path is given add this as a directory to the file name
     QString name;
     if (!path.isEmpty()) {
-        path.replace(QRegExp(QLatin1String("::")), QLatin1String("/")); // Simple hack!
-        name = path + QLatin1Char('/') + codeDocument->getFileName();
-        path = QLatin1Char('/') + path;
+        path.replace(QRegExp("::"), "/"); // Simple hack!
+        name = path + '/' + codeDocument->getFileName();
+        path = '/' + path;
     }
     else {  // determine the "natural" file name
         name = codeDocument->getFileName();
     }
 
     // Convert all "::" to "/" : Platform-specific path separator
-    name.replace(QRegExp(QLatin1String("::")), QLatin1String("/")); // Simple hack!
+    name.replace(QRegExp("::"), "/"); // Simple hack!
 
     // if a path name exists check the existence of the path directory
     if (!path.isEmpty()) {
@@ -681,26 +649,26 @@ QString CodeGenerator::findFileName(CodeDocument * codeDocument)
         // does our complete output directory exist yet? if not, try to create it
         if (!pathDir.exists()) {
             // ugh. dir separator here is UNIX specific..
-            const QStringList dirs = pathDir.absolutePath().split(QLatin1Char('/'));
+            const QStringList dirs = pathDir.absolutePath().split('/');
             QString currentDir;
 
             QStringList::const_iterator end(dirs.end());
             for (QStringList::const_iterator dir(dirs.begin()); dir != end; ++dir) {
-                currentDir += QLatin1Char('/') + *dir;
+                currentDir += '/' + *dir;
                 if (! (pathDir.exists(currentDir) || pathDir.mkdir(currentDir))) {
                     KMessageBox::error(0, i18n("Cannot create the folder:\n") +
                                        pathDir.absolutePath() + i18n("\nPlease check the access rights"),
                                        i18n("Cannot Create Folder"));
-                    return QString();
+                    return NULL;
                 }
             }
         }
     }
 
     name.simplified();
-    name.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    name.replace(QRegExp(" "),"_");
 
-    return overwritableName(name, codeDocument->getFileExtension());
+    return overwritableName( name, codeDocument->getFileExtension() );
 }
 
 /**
@@ -716,7 +684,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
     UMLPackage *temp;
     UMLAssociationList associations = c->getAssociations();
 
-    foreach (UMLAssociation *a, associations) {
+    foreach (UMLAssociation *a , associations) {
         temp = 0;
         switch (a->getAssocType()) {
         case Uml::AssociationType::Generalization:
@@ -762,7 +730,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
 
     //operations
     UMLOperationList opl(c->getOpList());
-    foreach(UMLOperation *op, opl) {
+    foreach(UMLOperation *op , opl ) {
         temp = 0;
         //check return value
         temp = (UMLClassifier*) op->getType();
@@ -771,7 +739,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
         }
         //check parameters
         UMLAttributeList atl = op->getParmList();
-        foreach(UMLAttribute *at, atl) {
+        foreach(UMLAttribute *at , atl) {
             temp = (UMLClassifier*)at->getType();
             if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
                 cList.append(temp);
@@ -782,7 +750,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
     //attributes
     if (!c->isInterface()) {
         UMLAttributeList atl = c->getAttributeList();
-        foreach (UMLAttribute *at, atl) {
+        foreach (UMLAttribute *at , atl ) {
             temp=0;
             temp = (UMLClassifier*) at->getType();
             if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
@@ -808,13 +776,13 @@ QString CodeGenerator::formatDoc(const QString &text, const QString &linePrefix,
     QStringList lines = text.split(endLine);
     for (QStringList::ConstIterator lit = lines.constBegin(); lit != lines.constEnd(); ++lit) {
         QString input = *lit;
-        input.remove(QRegExp(QLatin1String("\\s+$")));
+        input.remove( QRegExp("\\s+$") );
         if (input.length() < lineWidth) {
             output += linePrefix + input + endLine;
             continue;
         }
         int index;
-        while ((index = input.lastIndexOf(QLatin1String(" "), lineWidth)) >= 0) {
+        while ((index = input.lastIndexOf(" ", lineWidth)) >= 0) {
             output += linePrefix + input.left(index) + endLine; // add line
             input.remove(0, index + 1); // remove processed string, including white space
         }
@@ -926,3 +894,4 @@ void CodeGenerator::createDefaultStereotypes()
     //e.g.  m_document->createDefaultStereotypes("constructor");
 }
 
+#include "codegenerator.moc"
