@@ -5,8 +5,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2004-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "cppsourcecodeclassfielddeclarationblock.h"
@@ -14,17 +14,17 @@
 #include "cppcodeclassfield.h"
 #include "model_utils.h"
 
-CPPSourceCodeClassFieldDeclarationBlock::CPPSourceCodeClassFieldDeclarationBlock (CodeClassField * parent)
-        : CodeClassFieldDeclarationBlock (parent)
+CPPSourceCodeClassFieldDeclarationBlock::CPPSourceCodeClassFieldDeclarationBlock ( CodeClassField * parent )
+        : CodeClassFieldDeclarationBlock ( parent )
 {
     setOverallIndentationLevel(1);
 }
 
-CPPSourceCodeClassFieldDeclarationBlock::~CPPSourceCodeClassFieldDeclarationBlock ()
+CPPSourceCodeClassFieldDeclarationBlock::~CPPSourceCodeClassFieldDeclarationBlock ( )
 {
 }
 
-void CPPSourceCodeClassFieldDeclarationBlock::updateContent()
+void CPPSourceCodeClassFieldDeclarationBlock::updateContent( )
 {
     CodeClassField * cf = getParentClassField();
     CPPCodeClassField * jcf = dynamic_cast<CPPCodeClassField*>(cf);
@@ -34,16 +34,17 @@ void CPPSourceCodeClassFieldDeclarationBlock::updateContent()
     getComment()->setText(notes);
 
     // Set the body
-    QString staticValue = getParentObject()->isStatic() ? QLatin1String("static ") : QString();
+    QString staticValue = getParentObject()->isStatic() ? "static " : "";
     QString scopeStr = Uml::Visibility::toString(getParentObject()->visibility());
 
     QString typeName = jcf->getTypeName();
     QString fieldName = jcf->getFieldName();
     QString initialV = jcf->getInitialValue();
 
-    QString body = staticValue+scopeStr + QLatin1Char(' ') + typeName + QLatin1Char(' ') + fieldName;
+    QString body = staticValue+scopeStr + ' ' + typeName + ' ' + fieldName;
     if (!initialV.isEmpty())
-            body.append(QLatin1String(" = ") + initialV);
-    setText(body + QLatin1Char(';'));
+            body.append(" = " + initialV);
+    setText(body + ';');
 }
 
+#include "cppsourcecodeclassfielddeclarationblock.moc"
