@@ -6,8 +6,8 @@
  *                                                                         *
  *   copyright (C) 2005                                                    *
  *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2006-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -74,10 +74,10 @@ QString RubyClassifierCodeDocument::getPath()
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    path.replace(QRegExp(" "), "_");
 
-    path.replace(QRegExp(QLatin1String("\\.")),QLatin1String("/"));
-    path.replace(QRegExp(QLatin1String("::")), QLatin1String("/"));
+    path.replace(QRegExp("\\."),"/");
+    path.replace(QRegExp("::"), "/");
 
     path = path.toLower();
 
@@ -93,7 +93,7 @@ QString RubyClassifierCodeDocument::getRubyClassName(const QString &name)
 // Initialize this ruby classifier code document
 void RubyClassifierCodeDocument::init()
 {
-    setFileExtension(QLatin1String(".rb"));
+    setFileExtension(".rb");
 
     //initCodeClassFields(); // this is dubious because it calls down to
                              // CodeGenFactory::newCodeClassField(this)
@@ -124,7 +124,7 @@ void RubyClassifierCodeDocument::init()
 bool RubyClassifierCodeDocument::addCodeOperation(CodeOperation * op)
 {
     Uml::Visibility::Enum scope = op->getParentOperation()->visibility();
-    if (!op->getParentOperation()->isConstructorOperation())
+    if(!op->getParentOperation()->isConstructorOperation())
     {
         switch (scope) {
         default:
@@ -168,10 +168,10 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
     QDomNode tnode = root.firstChild();
     QDomElement telement = tnode.toElement();
     bool loadCheckForChildrenOK = false;
-    while (!telement.isNull()) {
+    while( !telement.isNull() ) {
         QString nodeName = telement.tagName();
 
-        if (nodeName == QLatin1String("textblocks")) {
+        if( nodeName == "textblocks" ) {
 
             QDomNode node = telement.firstChild();
             QDomElement element = node.toElement();
@@ -179,88 +179,100 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
             // if there is nothing to begin with, then we don't worry about it
             loadCheckForChildrenOK = element.isNull() ? true : false;
 
-            while (!element.isNull()) {
+            while( !element.isNull() ) {
                 QString name = element.tagName();
 
-                if (name == QLatin1String("codecomment")) {
+                if( name == "codecomment" ) {
                     CodeComment * block = new RubyCodeComment(this);
                     block->loadFromXMI(element);
-                    if (!addTextBlock(block)) {
+                    if(!addTextBlock(block))
+                    {
                         uError()<<"loadFromXMI : unable to add codeComment to :"<<this;
                         delete block;
-                    } else {
+                    } else
                         loadCheckForChildrenOK= true;
-                    }
-                } else if (name == QLatin1String("codeaccessormethod") ||
-                           name == QLatin1String("ccfdeclarationcodeblock")) {
-                    QString acctag = element.attribute(QLatin1String("tag"));
-                    // search for our method in the
-                    TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
-                    if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
-                        // DON'T delete
-                    } else {
-                        loadCheckForChildrenOK= true;
-                    }
-                } else if (name == QLatin1String("codeblock")) {
-                    CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI(element);
-                    if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
-                        delete block;
-                    } else {
-                        loadCheckForChildrenOK= true;
-                    }
-                } else if (name == QLatin1String("codeblockwithcomments")) {
-                    CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI(element);
-                    if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
-                        delete block;
-                    } else {
-                        loadCheckForChildrenOK= true;
-                    }
-                } else if (name == QLatin1String("header")) {
-                    // do nothing.. this is treated elsewhere
-                } else if (name == QLatin1String("hierarchicalcodeblock")) {
-                    HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI(element);
-                    if (!addTextBlock(block)) {
-                        uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
-                        delete block;
-                    } else {
-                        loadCheckForChildrenOK= true;
-                    }
-                } else if (name == QLatin1String("codeoperation")) {
-                    // find the code operation by id
-                    QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
-                    UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                    UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
-                    if (op) {
-                        CodeOperation * block = new RubyCodeOperation(this, op);
-                        block->loadFromXMI(element);
-                        if (addTextBlock(block)) {
+                } else
+                    if( name == "codeaccessormethod" ||
+                            name == "ccfdeclarationcodeblock"
+                      ) {
+                        QString acctag = element.attribute("tag","");
+                        // search for our method in the
+                        TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
+                        if(!tb || !addTextBlock(tb))
+                        {
+                            uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
+                            // DON'T delete
+                        } else
                             loadCheckForChildrenOK= true;
-                        } else {
-                            uError()<<"Unable to add codeoperation to:"<<this;
-                            block->deleteLater();
-                        }
-                    } else {
-                        uError()<<"Unable to find operation create codeoperation for:"<<this;
-                    }
-                } else if (name == QLatin1String("rubyclassdeclarationblock")) {
-                    RubyClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI(element);
-                    if (!addTextBlock(block)) {
-                        uError()<<"Unable to add ruby code declaration block to:"<<this;
-                        // DON'T delete.
-                        // block->deleteLater();
-                    } else {
-                        loadCheckForChildrenOK= true;
-                    }
-                } else {
-                    uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignoring";
-                }
+
+                    } else
+                        if( name == "codeblock" ) {
+                            CodeBlock * block = newCodeBlock();
+                            block->loadFromXMI(element);
+                            if(!addTextBlock(block))
+                            {
+                                uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
+                                delete block;
+                            } else
+                                loadCheckForChildrenOK= true;
+                        } else
+                            if( name == "codeblockwithcomments" ) {
+                                CodeBlockWithComments * block = newCodeBlockWithComments();
+                                block->loadFromXMI(element);
+                                if(!addTextBlock(block))
+                                {
+                                    uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
+                                    delete block;
+                                } else
+                                    loadCheckForChildrenOK= true;
+                            } else
+                                if( name == "header" ) {
+                                    // do nothing.. this is treated elsewhere
+                                } else
+                                    if( name == "hierarchicalcodeblock" ) {
+                                        HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
+                                        block->loadFromXMI(element);
+                                        if(!addTextBlock(block))
+                                        {
+                                            uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
+                                            delete block;
+                                        } else
+                                            loadCheckForChildrenOK= true;
+                                    } else
+                                        if( name == "codeoperation" ) {
+                                            // find the code operation by id
+                                            QString id = element.attribute("parent_id","-1");
+                                            UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
+                                            UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                                            if(op) {
+                                                CodeOperation * block = new RubyCodeOperation(this, op);
+                                                block->loadFromXMI(element);
+                                                if(addTextBlock(block))
+                                                    loadCheckForChildrenOK= true;
+                                                else
+                                                {
+                                                    uError()<<"Unable to add codeoperation to:"<<this;
+                                                    block->deleteLater();
+                                                }
+                                            } else
+                                                uError()<<"Unable to find operation create codeoperation for:"<<this;
+                                        } else
+                                            if( name == "rubyclassdeclarationblock" )
+                                            {
+                                                RubyClassDeclarationBlock * block = getClassDecl();
+                                                block->loadFromXMI(element);
+                                                if(!addTextBlock(block))
+                                                {
+                                                    uError()<<"Unable to add ruby code declaration block to:"<<this;
+                                                    // DON'T delete.
+                                                    // block->deleteLater();
+                                                } else
+                                                    loadCheckForChildrenOK= true;
+                                            }
+                // This last item is only needed for extreme debugging conditions
+                // (E.g. making new codeclassdocument loader)
+                // else
+                //        uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning";
 
                 node = element.nextSibling();
                 element = node.toElement();
@@ -272,19 +284,29 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
         telement = tnode.toElement();
     }
 
-    if (!loadCheckForChildrenOK)
+    if(!loadCheckForChildrenOK)
     {
-        uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: " << getFileName() << " " << this;
+        CodeDocument * test = dynamic_cast<CodeDocument*>(this);
+        if(test)
+        {
+            uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
+        } else {
+            HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
+            if(hb)
+                uWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
+            else
+                uDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
+        }
     }
 }
 
 RubyClassDeclarationBlock * RubyClassifierCodeDocument::getClassDecl()
 {
-    if (!classDeclCodeBlock)
+    if(!classDeclCodeBlock)
     {
         classDeclCodeBlock = new RubyClassDeclarationBlock (this);
         classDeclCodeBlock->updateContent();
-        classDeclCodeBlock->setTag(QLatin1String("ClassDeclBlock"));
+        classDeclCodeBlock->setTag("ClassDeclBlock");
     }
     return classDeclCodeBlock;
 }
@@ -321,35 +343,35 @@ void RubyClassifierCodeDocument::updateContent()
     const CodeClassFieldList * cfList = getCodeClassFieldList();
     CodeClassFieldList::const_iterator it = cfList->begin();
     CodeClassFieldList::const_iterator end = cfList->end();
-    for (; it != end; ++it) {
+    for( ; it != end; ++it) {
         CodeClassField * field = *it;
-        if (field->parentIsAttribute())
+        if(field->parentIsAttribute())
             field->setWriteOutMethods(gen->getAutoGenerateAttribAccessors());
         else
             field->setWriteOutMethods(gen->getAutoGenerateAssocAccessors());
     }
     // attribute-based ClassFields
     // we do it this way to have the static fields sorted out from regular ones
-    CodeClassFieldList staticPublicAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Public);
-    CodeClassFieldList publicAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, false, Uml::Visibility::Public);
-    CodeClassFieldList staticProtectedAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Protected);
-    CodeClassFieldList protectedAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, false, Uml::Visibility::Protected);
-    CodeClassFieldList staticPrivateAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Private);
+    CodeClassFieldList staticPublicAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Public );
+    CodeClassFieldList publicAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, false, Uml::Visibility::Public );
+    CodeClassFieldList staticProtectedAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Protected );
+    CodeClassFieldList protectedAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, false, Uml::Visibility::Protected );
+    CodeClassFieldList staticPrivateAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, true, Uml::Visibility::Private );
     CodeClassFieldList privateAttribClassFields = getSpecificClassFields (CodeClassField::Attribute, false, Uml::Visibility::Private);
 
     // association-based ClassFields
     // don't care if they are static or not..all are lumped together
-    CodeClassFieldList publicPlainAssocClassFields = getSpecificClassFields (CodeClassField::PlainAssociation, Uml::Visibility::Public);
-    CodeClassFieldList publicAggregationClassFields = getSpecificClassFields (CodeClassField::Aggregation, Uml::Visibility::Public);
-    CodeClassFieldList publicCompositionClassFields = getSpecificClassFields (CodeClassField::Composition, Uml::Visibility::Public);
+    CodeClassFieldList publicPlainAssocClassFields = getSpecificClassFields ( CodeClassField::PlainAssociation , Uml::Visibility::Public);
+    CodeClassFieldList publicAggregationClassFields = getSpecificClassFields ( CodeClassField::Aggregation, Uml::Visibility::Public);
+    CodeClassFieldList publicCompositionClassFields = getSpecificClassFields ( CodeClassField::Composition, Uml::Visibility::Public );
 
-    CodeClassFieldList protPlainAssocClassFields = getSpecificClassFields (CodeClassField::PlainAssociation, Uml::Visibility::Protected);
-    CodeClassFieldList protAggregationClassFields = getSpecificClassFields (CodeClassField::Aggregation, Uml::Visibility::Protected);
-    CodeClassFieldList protCompositionClassFields = getSpecificClassFields (CodeClassField::Composition, Uml::Visibility::Protected);
+    CodeClassFieldList protPlainAssocClassFields = getSpecificClassFields ( CodeClassField::PlainAssociation , Uml::Visibility::Protected);
+    CodeClassFieldList protAggregationClassFields = getSpecificClassFields ( CodeClassField::Aggregation, Uml::Visibility::Protected);
+    CodeClassFieldList protCompositionClassFields = getSpecificClassFields ( CodeClassField::Composition, Uml::Visibility::Protected);
 
-    CodeClassFieldList privPlainAssocClassFields = getSpecificClassFields (CodeClassField::PlainAssociation, Uml::Visibility::Private);
-    CodeClassFieldList privAggregationClassFields = getSpecificClassFields (CodeClassField::Aggregation, Uml::Visibility::Private);
-    CodeClassFieldList privCompositionClassFields = getSpecificClassFields (CodeClassField::Composition, Uml::Visibility::Private);
+    CodeClassFieldList privPlainAssocClassFields = getSpecificClassFields ( CodeClassField::PlainAssociation , Uml::Visibility::Private);
+    CodeClassFieldList privAggregationClassFields = getSpecificClassFields ( CodeClassField::Aggregation, Uml::Visibility::Private);
+    CodeClassFieldList privCompositionClassFields = getSpecificClassFields ( CodeClassField::Composition, Uml::Visibility::Private);
 
     bool isInterface = parentIsInterface();
     bool hasOperationMethods = false;
@@ -376,19 +398,19 @@ void RubyClassifierCodeDocument::updateContent()
     // declare public, protected and private methods, attributes (fields).
     // set the start text ONLY if this is the first time we created the objects.
     bool createdPublicBlock = publicBlock == 0 ? true : false;
-    publicBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("publicBlock"), QLatin1String("Public Items"), 0);
+    publicBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("publicBlock","Public Items",0);
     if (createdPublicBlock)
-        publicBlock->setStartText(QLatin1String("public"));
+        publicBlock->setStartText("public");
 
     bool createdProtBlock = protectedBlock == 0 ? true : false;
-    protectedBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("protectedBlock"), QLatin1String("Protected Items"), 0);
-    if (createdProtBlock)
-        protectedBlock->setStartText(QLatin1String("protected"));
+    protectedBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("protectedBlock","Protected Items",0);
+    if(createdProtBlock)
+        protectedBlock->setStartText("protected");
 
     bool createdPrivBlock = privateBlock == 0 ? true : false;
-    privateBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("privateBlock"), QLatin1String("Private Items"), 0);
-    if (createdPrivBlock)
-        privateBlock->setStartText(QLatin1String("private"));
+    privateBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("privateBlock","Private Items",0);
+    if(createdPrivBlock)
+        privateBlock->setStartText("private");
 
     // NOW create document in sections..
     // now we want to populate the body of our class
@@ -438,7 +460,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // get/create the method codeblock
     // public methods
-    HierarchicalCodeBlock * pubMethodsBlock = publicBlock->getHierarchicalCodeBlock(QLatin1String("pubMethodsBlock"), QString(), 1);
+    HierarchicalCodeBlock * pubMethodsBlock = publicBlock->getHierarchicalCodeBlock("pubMethodsBlock", "", 1);
     CodeComment * pubMethodsComment = pubMethodsBlock->getComment();
     bool forceDoc = pol->getCodeVerboseDocumentComments();
     // set conditions for showing this comment
@@ -448,7 +470,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubMethodsComment->setWriteOutText(true);
 
     // protected methods
-    HierarchicalCodeBlock * protMethodsBlock = protectedBlock->getHierarchicalCodeBlock(QLatin1String("protMethodsBlock"), QString(), 1);
+    HierarchicalCodeBlock * protMethodsBlock = protectedBlock->getHierarchicalCodeBlock("protMethodsBlock", "", 1);
     CodeComment * protMethodsComment = protMethodsBlock->getComment();
     // set conditions for showing this comment
     if (!forceDoc && !hasClassFields() && !hasOperationMethods)
@@ -457,7 +479,7 @@ void RubyClassifierCodeDocument::updateContent()
         protMethodsComment->setWriteOutText(true);
 
     // private methods
-    HierarchicalCodeBlock * privMethodsBlock = privateBlock->getHierarchicalCodeBlock(QLatin1String("privMethodsBlock"), QString(), 1);
+    HierarchicalCodeBlock * privMethodsBlock = privateBlock->getHierarchicalCodeBlock("privMethodsBlock", "", 1);
     CodeComment * privMethodsComment = privMethodsBlock->getComment();
     // set conditions for showing this comment
     if (!forceDoc && !hasClassFields() && !hasOperationMethods)
@@ -469,7 +491,7 @@ void RubyClassifierCodeDocument::updateContent()
     //
 
     // public
-    pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
+    pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * pubConstComment = pubConstructorBlock->getComment();
@@ -479,7 +501,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubConstComment->setWriteOutText(true);
 
     // protected
-    protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
+    protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * protConstComment = protConstructorBlock->getComment();
@@ -489,7 +511,7 @@ void RubyClassifierCodeDocument::updateContent()
         protConstComment->setWriteOutText(true);
 
     // private
-    privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
+    privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * privConstComment = privConstructorBlock->getComment();
@@ -500,7 +522,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // get/create the accessor codeblock
     // public
-    HierarchicalCodeBlock * pubAccessorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
+    HierarchicalCodeBlock * pubAccessorBlock = pubMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
     // set conditions for showing section comment
     CodeComment * pubAccessComment = pubAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -509,7 +531,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubAccessComment->setWriteOutText(true);
 
     // protected
-    HierarchicalCodeBlock * protAccessorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
+    HierarchicalCodeBlock * protAccessorBlock = protMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
     // set conditions for showing section comment
     CodeComment * protAccessComment = protAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -518,7 +540,7 @@ void RubyClassifierCodeDocument::updateContent()
         protAccessComment->setWriteOutText(true);
 
     // private
-    HierarchicalCodeBlock * privAccessorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
+    HierarchicalCodeBlock * privAccessorBlock = privMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
     // set conditions for showing section comment
     CodeComment * privAccessComment = privAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -528,18 +550,18 @@ void RubyClassifierCodeDocument::updateContent()
 
     // now, 2 sub-sub sections in accessor block
     // add/update accessor methods for attributes
-    HierarchicalCodeBlock * pubStaticAccessors = pubAccessorBlock->getHierarchicalCodeBlock(QLatin1String("pubStaticAccessorMethods"), QString(), 1);
-    HierarchicalCodeBlock * pubRegularAccessors = pubAccessorBlock->getHierarchicalCodeBlock(QLatin1String("pubRegularAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * pubStaticAccessors = pubAccessorBlock->getHierarchicalCodeBlock("pubStaticAccessorMethods", "", 1);
+    HierarchicalCodeBlock * pubRegularAccessors = pubAccessorBlock->getHierarchicalCodeBlock("pubRegularAccessorMethods", "", 1);
     pubStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     pubRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
 
-    HierarchicalCodeBlock * protStaticAccessors = protAccessorBlock->getHierarchicalCodeBlock(QLatin1String("protStaticAccessorMethods"), QString(), 1);
-    HierarchicalCodeBlock * protRegularAccessors = protAccessorBlock->getHierarchicalCodeBlock(QLatin1String("protRegularAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * protStaticAccessors = protAccessorBlock->getHierarchicalCodeBlock("protStaticAccessorMethods", "", 1);
+    HierarchicalCodeBlock * protRegularAccessors = protAccessorBlock->getHierarchicalCodeBlock("protRegularAccessorMethods", "", 1);
     protStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     protRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
 
-    HierarchicalCodeBlock * privStaticAccessors = privAccessorBlock->getHierarchicalCodeBlock(QLatin1String("privStaticAccessorMethods"), QString(), 1);
-    HierarchicalCodeBlock * privRegularAccessors = privAccessorBlock->getHierarchicalCodeBlock(QLatin1String("privRegularAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * privStaticAccessors = privAccessorBlock->getHierarchicalCodeBlock("privStaticAccessorMethods", "", 1);
+    HierarchicalCodeBlock * privRegularAccessors = privAccessorBlock->getHierarchicalCodeBlock("privRegularAccessorMethods", "", 1);
     privStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     privRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
     // now add in accessors as appropriate
@@ -571,28 +593,28 @@ void RubyClassifierCodeDocument::updateContent()
     // setup/get/create the operations codeblock
 
     // public
-    pubOperationsBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
+    pubOperationsBlock = pubMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
     // set conditions for showing section comment
     CodeComment * pubOcomment = pubOperationsBlock->getComment();
-    if (!forceDoc && !hasOperationMethods)
+    if (!forceDoc && !hasOperationMethods )
         pubOcomment->setWriteOutText(false);
     else
         pubOcomment->setWriteOutText(true);
 
     //protected
-    protOperationsBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
+    protOperationsBlock = protMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
     // set conditions for showing section comment
     CodeComment * protOcomment = protOperationsBlock->getComment();
-    if (!forceDoc && !hasOperationMethods)
+    if (!forceDoc && !hasOperationMethods )
         protOcomment->setWriteOutText(false);
     else
         protOcomment->setWriteOutText(true);
 
     //private
-    privOperationsBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
+    privOperationsBlock = privMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
     // set conditions for showing section comment
     CodeComment * privOcomment = privOperationsBlock->getComment();
-    if (!forceDoc && !hasOperationMethods)
+    if (!forceDoc && !hasOperationMethods )
         privOcomment->setWriteOutText(false);
     else
         privOcomment->setWriteOutText(true);
