@@ -6,8 +6,8 @@
  *                                                                         *
  *   copyright (C) 2005                                                    *
  *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2006-2011                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -22,7 +22,7 @@
 // qt includes
 #include <QRegExp>
 
-RubyCodeOperation::RubyCodeOperation (RubyClassifierCodeDocument * doc, UMLOperation *parent, const QString & body, const QString & comment)
+RubyCodeOperation::RubyCodeOperation ( RubyClassifierCodeDocument * doc, UMLOperation *parent, const QString & body, const QString & comment )
         : CodeOperation (doc, parent, body, comment)
 {
     // lets not go with the default comment and instead use
@@ -51,28 +51,28 @@ void RubyCodeOperation::updateMethodDeclaration()
     //:UNUSED: QString strVis = o->visibility().toString();
     // no return type for constructors
     QString fixedReturn = RubyCodeGenerator::cppToRubyType(o->getTypeName());
-    QString returnType = o->isConstructorOperation() ? QString() : (fixedReturn + QString(QLatin1String(" ")));
+    QString returnType = o->isConstructorOperation() ? QString("") : (fixedReturn + QString(" "));
     QString methodName = o->name();
 
     QString RubyClassName = rubydoc->getRubyClassName(c->name());
 
     // Skip destructors, and operator methods which
     // can't be defined in ruby
-    if (methodName.startsWith(QLatin1Char('~'))
-         || QRegExp(QLatin1String("operator\\s*(=|--|\\+\\+|!=)$")).exactMatch(methodName))
+    if ( methodName.startsWith('~')
+         || QRegExp("operator\\s*(=|--|\\+\\+|!=)$").exactMatch(methodName) )
     {
-        getComment()->setText(QString());
+        getComment()->setText("");
         return;
     }
 
     if (RubyClassName == methodName) {
-        methodName = QLatin1String("initialize");
+        methodName = "initialize";
     }
 
-    methodName.remove(QRegExp(QLatin1String("operator\\s*")));
+    methodName.remove(QRegExp("operator\\s*"));
     methodName = methodName.mid(0, 1).toLower() + methodName.mid(1);
 
-    QString paramStr;
+    QString paramStr = QString("");
     QStringList commentedParams;
 
     // assemble parameters
@@ -83,25 +83,25 @@ void RubyCodeOperation::updateMethodDeclaration()
         QString paramName = RubyCodeGenerator::cppToRubyName(parm->name());
         paramStr += paramName;
         if (! parm->getInitialValue().isEmpty()) {
-            paramStr += QString(QLatin1String(" = ")) + RubyCodeGenerator::cppToRubyType(parm->getInitialValue());
+            paramStr += QString(" = ") + RubyCodeGenerator::cppToRubyType(parm->getInitialValue());
         }
         paramNum++;
 
-        if (paramNum != nrofParam)
-            paramStr  += QLatin1String(", ");
+        if (paramNum != nrofParam )
+            paramStr  += ", ";
     }
 
     QString startText;
     if (isInterface) {
         // Assume 'isInterface' means a module in Ruby, so
         // generate module methods
-        startText = QLatin1String("def ") + RubyClassName + QLatin1Char('.') + methodName + QLatin1Char('(') + paramStr + QLatin1Char(')');
+        startText = "def "+ RubyClassName + '.' + methodName + '(' + paramStr +')';
     } else {
-        startText = QLatin1String("def ")+ methodName + QLatin1Char('(') + paramStr + QLatin1Char(')');
+        startText = "def "+ methodName + '(' + paramStr +')';
     }
 
-    // startText += "";  ???
-    setEndMethodText(QLatin1String("end"));
+    startText += "";
+    setEndMethodText("end");
 
     setStartMethodText(startText);
 
@@ -112,26 +112,26 @@ void RubyCodeOperation::updateMethodDeclaration()
     if (comment.isEmpty()) {
         if (contentType() == CodeBlock::AutoGenerated) {
             UMLAttributeList parameters = o->getParmList();
-            foreach (UMLAttribute* currentAtt, parameters) {
-                comment += endLine + QLatin1String("* _") + currentAtt->name() + QLatin1String("_ ");
-                comment += (QLatin1Char(' ') + currentAtt->doc().replace(QRegExp(QLatin1String("[\\n\\r]+[\\t ]*")), endLine + QLatin1String("  ")));
+            foreach (UMLAttribute* currentAtt, parameters ) {
+                comment += endLine + "* _" + currentAtt->name() + "_ ";
+                comment += (' ' + currentAtt->doc().replace( QRegExp("[\\n\\r]+[\\t ]*"), endLine + "  " ) );
             }
             // add a returns statement too
-            if (!returnType.isEmpty() && !QRegExp(QLatin1String("^void\\s*$")).exactMatch(returnType))
-                comment += endLine + QLatin1String("* _returns_ ") + returnType + QLatin1Char(' ');
+            if(!returnType.isEmpty() && !QRegExp("^void\\s*$").exactMatch(returnType))
+                comment += endLine + "* _returns_ " + returnType + ' ';
             getComment()->setText(comment);
         }
     } else {
-        comment.replace(QRegExp(QLatin1String("[\\n\\r]+ *")), endLine);
-        comment.replace(QRegExp(QLatin1String("[\\n\\r]+\\t*")), endLine);
+        comment.replace(QRegExp("[\\n\\r]+ *"), endLine);
+        comment.replace(QRegExp("[\\n\\r]+\\t*"), endLine);
 
-        comment.replace(QLatin1String(" m_"), QLatin1String(" "));
-        comment.replace(QRegExp(QLatin1String("\\s[npb](?=[A-Z])")), QLatin1String(" "));
-        QRegExp re_params(QLatin1String("@param (\\w)(\\w*)"));
+        comment.replace(" m_", " ");
+        comment.replace(QRegExp("\\s[npb](?=[A-Z])"), " ");
+        QRegExp re_params("@param (\\w)(\\w*)");
         int pos = re_params.indexIn(comment);
         while (pos != -1) {
-            comment.replace(re_params.cap(0),
-                            QString(QLatin1String("@param _")) + re_params.cap(1).toLower() + re_params.cap(2) + QLatin1Char('_'));
+            comment.replace( re_params.cap(0),
+                            QString("@param _") + re_params.cap(1).toLower() + re_params.cap(2) + '_' );
             commentedParams.append(re_params.cap(1).toLower() + re_params.cap(2));
 
             pos += re_params.matchedLength() + 3;
@@ -139,28 +139,28 @@ void RubyCodeOperation::updateMethodDeclaration()
         }
 
         UMLAttributeList parameters = o->getParmList();
-        foreach (UMLAttribute* currentAtt, parameters) {
+        foreach (UMLAttribute* currentAtt, parameters ) {
             // Only write an individual @param entry if one hasn't been found already
             // in the main doc comment
             if (commentedParams.contains(RubyCodeGenerator::cppToRubyName(currentAtt->name())) == 0) {
-                comment += (endLine + QLatin1String("@param _") + RubyCodeGenerator::cppToRubyName(currentAtt->name()) + QLatin1Char('_'));
+                comment += (endLine + "@param _" + RubyCodeGenerator::cppToRubyName(currentAtt->name()) + '_');
                 if (currentAtt->doc().isEmpty()) {
-                    comment += (QLatin1Char(' ') + RubyCodeGenerator::cppToRubyType(currentAtt->getTypeName()));
+                    comment += (' ' + RubyCodeGenerator::cppToRubyType(currentAtt->getTypeName()));
                 } else {
-                    comment += (QLatin1Char(' ') + currentAtt->doc().replace(QRegExp(QLatin1String("[\\n\\r]+[\\t ]*")), endLine + QLatin1String("  ")));
+                    comment += (' ' + currentAtt->doc().replace(QRegExp("[\\n\\r]+[\\t ]*"), endLine + "  "));
                 }
             }
         }
 
-        comment.remove(QLatin1String("@ref "));
-        comment.replace(QLatin1String("@param"), QLatin1String("*"));
-        comment.replace(QLatin1String("@return"), QLatin1String("* _returns_"));
+        comment.remove("@ref ");
+        comment.replace("@param", "*");
+        comment.replace("@return", "* _returns_");
 
         // All lines after the first one starting with '*' in the doc comment
         // must be indented correctly. If they aren't a list
         // item starting with '*', then indent the text with
         // two spaces, '  ', to line up with the list item.
-        pos = comment.indexOf(endLine + QLatin1Char('*'));
+        pos = comment.indexOf(endLine + '*');
         if (pos != -1) {
             pos += endLine.length() + 1;
             pos = comment.indexOf(endLine, pos);
@@ -168,8 +168,8 @@ void RubyCodeOperation::updateMethodDeclaration()
 
         while (pos > 0) {
             pos += endLine.length();
-            if (comment[pos] != QLatin1Char('*')) {
-                comment.insert(pos, QLatin1String("  "));
+            if (comment[pos] != '*') {
+                comment.insert(pos, "  ");
                 pos += 2;
             }
 
@@ -177,11 +177,11 @@ void RubyCodeOperation::updateMethodDeclaration()
         }
 
         QString typeStr = RubyCodeGenerator::cppToRubyType(o->getTypeName());
-        if (!typeStr.isEmpty()
-                && !QRegExp(QLatin1String("^void\\s*$")).exactMatch(typeStr)
-                && comment.contains(QLatin1String("_returns_")) == 0)
+        if ( !typeStr.isEmpty()
+                && !QRegExp("^void\\s*$").exactMatch(typeStr)
+                && comment.contains("_returns_") == 0 )
         {
-            comment += endLine + QLatin1String("* _returns_ ") + typeStr;
+            comment += endLine + "* _returns_ " + typeStr;
         }
 
         getComment()->setText(comment);
@@ -191,7 +191,7 @@ void RubyCodeOperation::updateMethodDeclaration()
     // method declarations. And for Ruby modules?
     if (isInterface) {
         UMLOperation * o = getParentOperation();
-        if (o->visibility() != Uml::Visibility::Public)
+        if(o->visibility() != Uml::Visibility::Public)
             setWriteOutText(false);
     }
 
@@ -200,9 +200,10 @@ void RubyCodeOperation::updateMethodDeclaration()
 int RubyCodeOperation::lastEditableLine()
 {
     ClassifierCodeDocument * doc = dynamic_cast<ClassifierCodeDocument*>(getParentDocument());
-    if (doc->parentIsInterface())
+    if(doc->parentIsInterface())
         return -1; // very last line is NOT editable as its a one-line declaration w/ no body in
     // an interface.
     return 0;
 }
 
+#include "rubycodeoperation.moc"
