@@ -4,22 +4,17 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2006-2011                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 #ifndef EXPORTALLVIEWSDIALOG_H
 #define EXPORTALLVIEWSDIALOG_H
 
 // application specific includes
 #include "ui_exportallviewsdialogbase.h"
-#include "singlepagedialogbase.h"
 
 // KDE forward declarations
-#if QT_VERSION >= 0x050000
-class KComboBox;
-#else
 class KFileFilterCombo;
-#endif
 
 /**
  * Dialog for collecting the "Export all views" params.
@@ -29,23 +24,22 @@ class KFileFilterCombo;
  * The KFileFilterCombo is declared here instead of in the .ui file because QT
  * Designer and uic don't recognize it.
  */
-class ExportAllViewsDialog : public SinglePageDialogBase, private Ui::ExportAllViewsDialogBase
+class ExportAllViewsDialog : public KDialog, private Ui::ExportAllViewsDialogBase
 {
   Q_OBJECT
 
 public:
 
-    explicit ExportAllViewsDialog(QWidget* parent = 0, const char* name = 0);
+    explicit ExportAllViewsDialog(QWidget* parent = 0, const char* name = 0,
+                         bool modal = false, Qt::WindowFlags fl = 0,
+                         const QString& defaultMimeType = "image/png");
 
     ~ExportAllViewsDialog();
 
 private:
 
-#if QT_VERSION >= 0x050000
-    KComboBox* m_imageType;  ///< The image type selected.
-#else
     KFileFilterCombo* m_imageType;  ///< The image type selected.
-#endif
+
 protected slots:
 
     friend class UMLViewImageExporterAll;
